@@ -38,6 +38,7 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <string.h>
 #include <math.h>
+#include <unistd.h>
 
 /*
  * This server does not support these XFree86 4.0 features yet
@@ -52,8 +53,10 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 #include "xf86.h"
 #include "xf86_OSproc.h"
+#if GET_ABI_MAJOR(ABI_VIDEODRV_VERSION) < 6
 #include "xf86Resources.h"
 #include "xf86RAC.h"
+#endif
 #include "xf86cmap.h"
 
 /* If the driver uses port I/O directly, it needs: */
@@ -187,54 +190,6 @@ static const OptionInfoRec I740Options[] = {
   { -1, NULL, OPTV_NONE, {0}, FALSE}
 };
 
-static const char *vgahwSymbols[] = {
-    "vgaHWGetHWRec",
-    "vgaHWSave", /* Added */
-    "vgaHWRestore", /* Added */
-    "vgaHWProtect",
-    "vgaHWInit",
-    "vgaHWMapMem",
-    "vgaHWSetMmioFuncs",
-    "vgaHWGetIOBase",
-    "vgaHWLock",
-    "vgaHWUnlock",
-    "vgaHWFreeHWRec",
-    "vgaHWSaveScreen",
-    "vgaHWHandleColormaps",
-    0
-};
-
-#ifdef XFree86LOADER
-static const char *fbSymbols[] = {
-    "fbScreenInit",
-    "fbPictureInit",
-    NULL
-};
-#endif
-
-static const char *xaaSymbols[] = {
-    "XAADestroyInfoRec",
-    "XAACreateInfoRec",
-    "XAAInit",
-    NULL
-};
-
-static const char *ramdacSymbols[] = {
-    "xf86InitCursor",
-    "xf86CreateCursorInfoRec",
-    "xf86DestroyCursorInfoRec",
-    NULL
-};
-
-#ifdef XFree86LOADER
-static const char *vbeSymbols[] = {
-    "VBEInit",
-    "vbeDoEDID",
-    "vbeFree",
-    NULL
-};
-#endif
-
 #ifdef XFree86LOADER
 
 static MODULESETUPPROTO(i740Setup);
@@ -271,14 +226,6 @@ i740Setup(pointer module, pointer opts, int *errmaj, int *errmin)
 	 * by calling LoadSubModule().
 	 */
 
-	/*
-	 * Tell the loader about symbols from other modules that this module
-	 * might refer to.
-	 */
-	LoaderRefSymLists(vgahwSymbols, fbSymbols, xaaSymbols, 
-			  ramdacSymbols, vbeSymbols,
-			  NULL);
-
 	/*
 	 * The return value must be non-NULL on success even though there
 	 * is no TearDownProc.
@@ -310,8 +257,7 @@ I740GetRec(ScrnInfoPtr pScrn) {
 static void
 I740FreeRec(ScrnInfoPtr pScrn) {
   if (!pScrn) return;
-  if (!pScrn->driverPrivate) return;
-  xfree(pScrn->driverPrivate);
+  free(pScrn->driverPrivate);
   pScrn->driverPrivate=0;
 }
 
@@ -425,8 +371,8 @@ I740Probe(DriverPtr drv, int flags) {
       }
   }
   
-  xfree(devSections);
-  xfree(usedChips);
+  free(devSections);
+  free(usedChips);
   
   return foundScreen;
 }
@@ -481,16 +427,14 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
   /* The vgahw module should be loaded here when needed */
   if (!xf86LoadSubModule(pScrn, "vgahw")) return FALSE;
 
-  xf86LoaderReqSymLists(vgahwSymbols, NULL);
-
   /* Allocate a vgaHWRec */
   if (!vgaHWGetHWRec(pScrn)) return FALSE;
+  vgaHWSetStdFuncs(VGAHWPTR(pScrn));
 
   pI740->PciInfo = xf86GetPciInfoForEntity(pI740->pEnt->index);
 #ifndef XSERVER_LIBPCIACCESS
   pI740->PciTag = pciTag(pI740->PciInfo->bus, pI740->PciInfo->device,
 			 pI740->PciInfo->func);
-#endif
 
   if (xf86RegisterResources(pI740->pEnt->index, 0, ResNone))
       return FALSE;
@@ -498,7 +442,7 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
     pScrn->racIoFlags = RAC_FB | RAC_COLORMAP;
   else
     pScrn->racMemFlags = RAC_FB | RAC_COLORMAP;
-
+#endif
   /* Set pScrn->monitor */
   pScrn->monitor = pScrn->confScreen->monitor;
 
@@ -544,7 +488,7 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
 
   /* Process the options */
   xf86CollectOptions(pScrn, NULL);
-  if (!(pI740->Options = xalloc(sizeof(I740Options))))
+  if (!(pI740->Options = malloc(sizeof(I740Options))))
     return FALSE;
   memcpy(pI740->Options, I740Options, sizeof(I740Options));
   xf86ProcessOptions(pScrn->scrnIndex, pScrn->options, pI740->Options);
@@ -781,14 +725,13 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
     I740FreeRec(pScrn);
     return FALSE;
   }
-  xf86LoaderReqSymbols("fbScreenInit","fbPictureInit", NULL);
 
-  if (!xf86ReturnOptValBool(pI740->Options, OPTION_NOACCEL, FALSE)) {
+  pI740->NoAccel = xf86ReturnOptValBool(pI740->Options, OPTION_NOACCEL, FALSE);
+  if (!pI740->NoAccel) {
     if (!xf86LoadSubModule(pScrn, "xaa")) {
-      I740FreeRec(pScrn);
-      return FALSE;
+      xf86DrvMsg(pScrn->scrnIndex, X_WARNING, "No acceleration available\n");
+      pI740->NoAccel = 1;
     }
-    xf86LoaderReqSymLists(xaaSymbols, NULL);
   }
 
   if (!xf86ReturnOptValBool(pI740->Options, OPTION_SW_CURSOR, FALSE)) {
@@ -796,11 +739,11 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
       I740FreeRec(pScrn);
       return FALSE;
     }
-    xf86LoaderReqSymLists(ramdacSymbols, NULL);
   }
 
   /*  We wont be using the VGA access after the probe */
   if (!xf86ReturnOptValBool(pI740->Options, OPTION_USE_PIO, FALSE)) {
+#ifndef XSERVER_LIBPCIACCESS
     resRange vgaio[] = { {ResShrIoBlock,0x3B0,0x3BB},
 			 {ResShrIoBlock,0x3C0,0x3DF},
 			 _END };
@@ -808,11 +751,13 @@ I740PreInit(ScrnInfoPtr pScrn, int flags) {
 			 {ResShrMemBlock,0xB8000,0xBFFFF},
 			 {ResShrMemBlock,0xB0000,0xB7FFF},
 			 _END };
-
+#endif
     pI740->usePIO=FALSE;
     I740SetMMIOAccess(pI740);
+#ifndef XSERVER_LIBPCIACCESS
     xf86SetOperatingState(vgaio, pI740->pEnt->index, ResUnusedOpr);
     xf86SetOperatingState(vgamem, pI740->pEnt->index, ResDisableOpr);
+#endif
   } else {
     pI740->usePIO=TRUE;
   }
@@ -1592,7 +1537,7 @@ I740ScreenInit(int scrnIndex, ScreenPtr pScreen, int argc, char **argv) {
     return FALSE;
   }
 
-  if (!xf86ReturnOptValBool(pI740->Options, OPTION_NOACCEL, FALSE)) {
+  if (!pI740->NoAccel) {
     if (!I740AccelInit(pScreen)) {
       xf86DrvMsg(pScrn->scrnIndex, X_ERROR,
 		 "Hardware acceleration initialization failed\n");
